@@ -436,43 +436,6 @@ class ForceCacheInvalidationTest(TestCase):
     def test_header_not_set(self):
         self.assertFalse(utils.force_cache_invalidation(self.factory.get('/')))
 
-    @override_settings(INTERNAL_IPS=['10.0.0.1'])
-    def test_remote_anonymous(self):
-        request = self.factory.get('/')
-        request.META.update(
-            {'HTTP_CACHE_CONTROL': 'no-cache',
-             'REMOTE_ADDR': '10.0.0.2'})
-        request.user = AnonymousUser()
-        self.assertFalse(utils.force_cache_invalidation(request))
-
-    @override_settings(INTERNAL_IPS=['10.0.0.1'])
-    def test_internal_ip(self):
-        request = self.factory.get('/')
-        request.META.update(
-            {'HTTP_CACHE_CONTROL': 'no-cache',
-             'REMOTE_ADDR': '10.0.0.1'})
-        request.user = AnonymousUser()
-        self.assertTrue(utils.force_cache_invalidation(request))
-
-    @override_settings(INTERNAL_IPS=['10.0.0.1'])
-    def test_internal_ip_forwarded(self):
-        request = self.factory.get('/')
-        request.META.update(
-            {'HTTP_CACHE_CONTROL': 'no-cache',
-             'HTTP_X_FORWARDED_FOR': '10.0.0.1',
-             'REMOTE_ADDR': '10.0.0.2'})
-        request.user = AnonymousUser()
-        self.assertTrue(utils.force_cache_invalidation(request))
-
-    @override_settings(INTERNAL_IPS=['10.0.0.1'])
-    def test_superuser_external_ip(self):
-        request = self.factory.get('/')
-        request.META.update(
-            {'HTTP_CACHE_CONTROL': 'no-cache',
-             'REMOTE_ADDR': '10.0.0.2'})
-        request.user = any_user(is_superuser=True)
-        self.assertTrue(utils.force_cache_invalidation(request))
-
 
 class SitemapTest(TestCase):
     def setUp(self):
@@ -488,7 +451,8 @@ class SitemapTest(TestCase):
         self.cache_key = '%s%s_sitemap' % (
             settings.URLOGRAPHER_CACHE_PREFIX, self.site)
         self.request = self.factory.get('/sitemap.xml')
-        self.mock_contrib_sitemap_response = HttpResponse(content='<mock>Sitemap</mock>')
+        self.mock_contrib_sitemap_response = HttpResponse(
+            content='<mock>Sitemap</mock>')
         self.mock_contrib_sitemap_response.render = lambda: None
         self.mox.StubOutWithMock(self.mock_contrib_sitemap_response, 'render')
 
